==> spip_4.0.4.orig.tar.xz: plugins-dist/medias/lang/medias_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=fa
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aucun_audio' => 'بدون تراك صدا',
	'aucun_document' => 'بدون سند',
	'aucun_file' => 'بدون سند ',
	'aucun_image' => 'بدون تصوير',
	'aucun_video' => 'بدون سكانس',
	'aucune_utilisation' => 'از اين سند استفاده نمي‌شود',
	'aucune_vignette' => 'بدون صورتك',

	// B
	'bouton_ajouter_document' => 'يك سند اضافه كنيد',
	'bouton_ajouter_image' => 'يك تصوير اضافه كنيد',
	'bouton_ajouter_image_document' => 'اضافه كردن يك تصوير يا يك سند',
	'bouton_attacher_document' => 'پيوست',
	'bouton_copier_local' => 'كپي در سايت',
	'bouton_download_depuis' => 'از :',
	'bouton_download_local' => 'كامپيوتر من',
	'bouton_download_par_ftp' => 'سرور',
	'bouton_download_par_mediatheque' => 'آرشيورسانه',
	'bouton_download_sur_le_web' => 'اينترنت',
	'bouton_enlever_document' => 'تفكيك',
	'bouton_enlever_supprimer_document' => 'حذف',
	'bouton_enlever_supprimer_document_confirmation' => 'حتماً مي‌خواهيد اين سند را حذف كنيد؟',
	'bouton_modifier_document' => 'اصلاح',
	'bouton_parcourir' => 'طي كردن. . . ',
	'bouton_refresh_document' => 'تازه ‌سازي',
	'bouton_remplacer_document' => 'جايگزين كردن اين سند',
	'bouton_remplacer_image' => 'جايگزين كردن اين تصوير',
	'bouton_remplacer_image_document' => 'جايگزين كردن با اين تصوير يا اين سند ',
	'bouton_supprimer' => 'حذف',
	'bouton_supprimer_tous_orphelins' => 'حذف تمام سطر‌هاي يتيم', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'آيا حتماً مي‌خواهيد @nb@ سطر يتيم را حذف كنيد؟‌', # MODIF
	'bouton_upload' => 'بارگذاري',

	// D
	'des_audios' => '@nb@ تراك صدا',
	'des_documents' => '@nb@ سند',
	'des_files' => '@nb@ سند',
	'des_images' => '@nb@ تصوير',
	'des_utilisations' => '@nb@ استفاده',
	'des_videos' => '@nb@ سكانس',
	'descriptif' => 'توصيف ',
	'document_attache_succes' => 'سند افزوده شده',
	'document_copie_locale_succes' => 'اين پرونده داخل سايت كپي شده است',
	'document_installe_succes' => 'اين پرونده بارگذاري شده است',
	'document_vu' => 'گنجاندن در متن ',
	'documents' => 'آرشيو رسانه',
	'documents_brises' => 'شكسته‌ها',
	'documents_distants' => 'راه دور',
	'documents_locaux' => 'مقدمات',
	'documents_non_publies' => 'منتشر نشده‌ها',
	'documents_orphelins' => 'اسفتاده‌ نشده',
	'documents_publies' => 'منشر شده',
	'documents_tous' => 'همه',
	'double_clic_inserer_doc' => 'براى گنجاندن اين راه كوتاه در متن, دوبار كليك كنيد.',

	// E
	'entree_dimensions' => ': ابعاد',
	'entree_titre_document' => ': عنوان سند',
	'entree_titre_image' => ': عنوان تصوير',
	'erreur_aucun_document' => 'اين سند در آرشيو رسانه نيست',
	'erreur_aucun_fichier' => 'هيچ پرونده‌اي يافت نشده ',
	'erreur_chemin_distant' => 'پرونده‌ي دور @nom@ يافت نشده ',
	'erreur_chemin_ftp' => 'پرونده‌ي مورد نظر روي سرور يافت نشده',
	'erreur_copie_fichier' => 'كپي كردن پرونده‌ي  @nom@ روي جايگزين نهايي آن غيرممكن است',
	'erreur_dossier_tmp_manquant' => 'يك پوشه موقت براي بارگذاري اين پرونده‌ها نيست',
	'erreur_ecriture_fichier' => 'خطا نوشتن پرونده روي ديسك',
	'erreur_format_fichier_image' => 'فرمت  @nom@ براي تصوير مناسب نيست',
	'erreur_indiquez_un_fichier' => 'يك پرونده را مشخص كنيد!',
	'erreur_insertion_document_base' => 'ثبت سند  @fichier@در پايگاه داده‌هاي سرور ممكن نيست ',
	'erreur_suppression_vignette' => 'خطاي حذف صورتك‌ها',
	'erreur_upload_type_interdit' => 'بارگذاري  پرونده‌هاي نوع @nom@ مجاز نيست  ',
	'erreur_upload_vignette' => 'خطاي بارگذاري صورتك‌هاي  @nom@',
	'erreurs' => '@nb@ خطا  ',
	'erreurs_voir' => 'ديدن @nb@ خطا',

	// F
	'fichier_distant' => 'پرونده‌ي راه دور',
	'fichier_manquant' => 'پرونده‌ي ناقص',
	'fichier_modifie' => 'پرونده اصلاح شده است. روي ثبت كليك كنيد.',
	'format_date_incorrect' => 'تاريخ يا ساعت درست نيستند',

	// I
	'icone_creer_document' => 'افزودن يك سند',
	'id' => 'آي.دي',
	'image_tourner_180' => 'چرخش °١٨٠ ',
	'image_tourner_droite' => 'چرخش ٩٠ درجه به راست',
	'image_tourner_gauche' => 'چرخش ٩٠ درجه به چپ',
	'info_doc_max_poids' => 'سندها الزاماً بايد كم‌تر از @maxi@ باشند. (اين پرونده @actuel@ است(  ',
	'info_document' => 'سند',
	'info_document_indisponible' => 'این سند موجود نمیباشد',
	'info_documents' => 'اسناد',
	'info_gauche_numero_document' => 'شماره‌ي سند',
	'info_hauteur' => 'بلندي',
	'info_heure' => 'ساعت',
	'info_illustrations' => 'ترسيم‌ها',
	'info_image_max_poids' => 'تصويرها بايد الزام كم‌تر از @maxi@ باشند(اين پرونده @actuel@ است).',
	'info_image_max_taille' => 'تصويرها بايد الزام كم‌تر از @maxi@ باشند(اين پرونده @actuel@ است).',
	'info_inclusion_directe' => ': گنجاندن مستقيم',
	'info_inclusion_vignette' => ': گنجاندن تصاوير كوچك شده',
	'info_installer_tous_documents' => 'تمام اسناد را مستقر كنيد',
	'info_largeur' => 'درازا',
	'info_logo_max_taille' => 'لوگوها بايد كمتر از @maxi@ باشند(اين فايل است)',
	'info_modifier_document' => 'اصلاح سند ',
	'info_portfolio' => 'كارنامه',
	'info_referencer_doc_distant' => 'يك پرونده را در اينترنت ضبط كنيد:',
	'info_sans_vignette' => 'بدون صورتك ',
	'info_statut_document' => 'اين سند :',
	'info_telecharger' => ':با رايانه خودتان بارگذارى كنيد',
	'infos' => ' نمايش اطلاعات روي تمام بخش‌ها (اگرمي‌خواهيد استفاده‌ي متفاوتي از آن بشود)',
	'item_autoriser_selectionner_date_en_ligne' => 'دادن اجازه‌ي اصلاح تاريخ هر سند',
	'item_non_autoriser_selectionner_date_en_ligne' => 'تاريخ سند‌ها تاريخ افزوده شدن‌ آن‌ها به سايت است',

	// L
	'label_activer_document_objets' => 'فعال سازي بارگذاري براي اين مطالب: ',
	'label_apercu' => 'مرور',
	'label_caracteristiques' => 'ويژگي‌ها',
	'label_credits' => 'اعتبارها',
	'label_fichier' => 'پرونده',
	'label_fichier_vignette' => 'ويگنت',
	'label_paginer_par' => 'شماره صفحه‌گذاري با: ',
	'label_parents' => 'اين سند پيوند خورده به ',
	'label_refdoc_joindre' => 'شماره‌ي سند',
	'lien_tout_enlever' => 'حذف همه', # MODIF
	'logo' => 'لوگو',

	// M
	'media_audio' => 'تراك صدا',
	'media_file' => 'ديگران',
	'media_image' => 'تصويرها',
	'media_video' => 'سكانس‌ها',
	'miniature_automatique_active' => ' اسپيپ به طور خوكار يك مينياتور از تصوير درست مي‌كند',

	// N
	'nb_documents_attache_succes' => '@nb@ سند افزوده شه است',
	'nb_documents_installe_succes' => '@nb@ پرونده با موفقيت بارگداري شده',

	// O
	'objet_document' => 'سند',
	'objet_documents' => 'سندها',

	// P
	'par_date' => 'بر اساس تاريخ',
	'par_hauteur' => 'بلندي',
	'par_id' => 'آي.دي',
	'par_largeur' => 'درازا',
	'par_taille' => 'وزن',
	'par_titre' => 'بر اساس تيتر',

	// T
	'texte_documents_joints' => 'مي‌توانيد واسطه‌ي افزودن سندها (فايل‌هاي اداري، تصويرها، و چندرسانه‌اي و غيره) را به مقاله‌ها، بخش‌ها و غيره فعال كنيد. به اين پرونده‌ها بعداً مي‌توان در متن، ارجاع كرد يا آن‌ها را جداگانه به نمايش گذاشت.</p> ',
	'texte_documents_joints_2' => 'اين تنظيم نه از بارگذاري تصاوير در مقالات و نه از گنجاندن مستقيم سند در مت‌هاي مطالب جلوگيرى نمي‌كند.',
	'titre_documents_joints' => 'اسناد پيوسته',
	'titre_page_documents_edit' => 'اصلاح سند : @titre@',
	'tous_les_medias' => 'تمام رسانه‌ها',
	'tout_dossier_upload' => 'تمام پرونده @upload@',
	'tout_voir' => 'ديدن همه',

	// U
	'un_audio' => '1 تراك صدا',
	'un_document' => '1 سند',
	'un_file' => '1 سند',
	'un_image' => '1 تصوير',
	'un_video' => '1 سكانس',
	'une_utilisation' => '1اسفتاده',
	'upload_fichier_zip' => 'فايل فشرده ZIP',
	'upload_fichier_zip_texte' => 'فايلى كه شما پيشنهاد نصب آنرا ميكنيد يك فايل  ZIP ميباشد.',
	'upload_fichier_zip_texte2' => 'اين فايل ميتواند',
	'upload_info_mode_document' => 'گذاشتن اين تصويرها در شرح‌ حال',
	'upload_info_mode_image' => 'برداشتن اين تصوير از شرح حال',
	'upload_limit' => 'اين فايل براى سرور بسيار بزرگ است حداكثر اندازه ى مجاز <i>upload</i> @max@ ميباشد',
	'upload_zip_conserver' => 'حفظ كردن فايل آرشيوي پس از استخراج محتواي آن',
	'upload_zip_decompacter' => 'باز شود و هر عنصر محتوى آن ميتواند بروى سايت نصب شود. فايلهايى كه بدين صورت نصب ميشوند',
	'upload_zip_mode_document' => 'گذاشتن تمام اين تصويرها در شرح حال',
	'upload_zip_telquel' => 'بهمان صورت نصب شده اند بصورت بايگانى ZIP',
	'upload_zip_titrer' => 'مطابق با نام پرونده تيترگذاري كن',

	// V
	'verifier_documents_brises' => 'اصلاح پرونده‌هاي ناقص',
	'verifier_documents_inutilises' => 'تأييد پيوند‌ها به سندها',
	'vignette_supprimee' => 'ويگنت‌ها حذف شده‌اند'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/medias/lang/medias_fa.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/medias?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// A
	'aucun_audio' => 'بدون تراك صدا',
	'aucun_document' => 'بدون سند',
	'aucun_file' => 'بدون سند ',
	'aucun_image' => 'بدون تصوير',
	'aucun_video' => 'بدون سكانس',
	'aucune_utilisation' => 'از اين سند استفاده نمي‌شود',
	'aucune_vignette' => 'بدون صورتك',

	// B
	'bouton_ajouter_document' => 'يك سند اضافه كنيد',
	'bouton_ajouter_image' => 'يك تصوير اضافه كنيد',
	'bouton_ajouter_image_document' => 'اضافه كردن يك تصوير يا يك سند',
	'bouton_attacher_document' => 'پيوست',
	'bouton_copier_local' => 'كپي در سايت',
	'bouton_download_depuis' => 'از :',
	'bouton_download_local' => 'كامپيوتر من',
	'bouton_download_par_ftp' => 'سرور',
	'bouton_download_par_mediatheque' => 'آرشيورسانه',
	'bouton_download_sur_le_web' => 'اينترنت',
	'bouton_enlever_document' => 'تفكيك',
	'bouton_enlever_supprimer_document' => 'حذف',
	'bouton_enlever_supprimer_document_confirmation' => 'حتماً مي‌خواهيد اين سند را حذف كنيد؟',
	'bouton_modifier_document' => 'اصلاح',
	'bouton_parcourir' => 'طي كردن. . . ',
	'bouton_refresh_document' => 'تازه ‌سازي',
	'bouton_remplacer_document' => 'جايگزين كردن اين سند',
	'bouton_remplacer_image' => 'جايگزين كردن اين تصوير',
	'bouton_remplacer_image_document' => 'جايگزين كردن با اين تصوير يا اين سند ',
	'bouton_supprimer' => 'حذف',
	'bouton_supprimer_tous_orphelins' => 'حذف تمام سطر‌هاي يتيم', # MODIF
	'bouton_supprimer_tous_orphelins_confirmation' => 'آيا حتماً مي‌خواهيد @nb@ سطر يتيم را حذف كنيد؟‌', # MODIF
	'bouton_upload' => 'بارگذاري',

	// D
	'des_audios' => '@nb@ تراك صدا',
	'des_documents' => '@nb@ سند',
	'des_files' => '@nb@ سند',
	'des_images' => '@nb@ تصوير',
	'des_utilisations' => '@nb@ استفاده',
	'des_videos' => '@nb@ سكانس',
	'descriptif' => 'توصيف ', # MODIF
	'document_attache_succes' => 'سند افزوده شده',
	'document_copie_locale_succes' => 'اين پرونده داخل سايت كپي شده است',
	'document_installe_succes' => 'اين پرونده بارگذاري شده است',
	'document_vu' => 'گنجاندن در متن ',
	'documents' => 'آرشيو رسانه',
	'documents_brises' => 'شكسته‌ها',
	'documents_distants' => 'راه دور',
	'documents_locaux' => 'مقدمات',
	'documents_non_publies' => 'منتشر نشده‌ها',
	'documents_orphelins' => 'اسفتاده‌ نشده',
	'documents_publies' => 'منشر شده',
	'documents_tous' => 'همه',
	'double_clic_inserer_doc' => 'براى گنجاندن اين راه كوتاه در متن, دوبار كليك كنيد.',

	// E
	'entree_dimensions' => ': ابعاد',
	'entree_titre_document' => ': عنوان سند',
	'entree_titre_image' => ': عنوان تصوير',
	'erreur_aucun_document' => 'اين سند در آرشيو رسانه نيست',
	'erreur_aucun_fichier' => 'هيچ پرونده‌اي يافت نشده ',
	'erreur_chemin_distant' => 'پرونده‌ي دور @nom@ يافت نشده ',
	'erreur_chemin_ftp' => 'پرونده‌ي مورد نظر روي سرور يافت نشده',
	'erreur_copie_fichier' => 'كپي كردن پرونده‌ي  @nom@ روي جايگزين نهايي آن غيرممكن است',
	'erreur_dossier_tmp_manquant' => 'يك پوشه موقت براي بارگذاري اين پرونده‌ها نيست',
	'erreur_ecriture_fichier' => 'خطا نوشتن پرونده روي ديسك',
	'erreur_format_fichier_image' => 'فرمت  @nom@ براي تصوير مناسب نيست',
	'erreur_indiquez_un_fichier' => 'يك پرونده را مشخص كنيد!',
	'erreur_insertion_document_base' => 'ثبت سند  @fichier@در پايگاه داده‌هاي سرور ممكن نيست ',
	'erreur_suppression_vignette' => 'خطاي حذف صورتك‌ها',
	'erreur_upload_type_interdit' => 'بارگذاري  پرونده‌هاي نوع @nom@ مجاز نيست  ',
	'erreur_upload_vignette' => 'خطاي بارگذاري صورتك‌هاي  @nom@',
	'erreurs' => '@nb@ خطا  ',
	'erreurs_voir' => 'ديدن @nb@ خطا',

	// F
	'fichier_distant' => 'پرونده‌ي راه دور',
	'fichier_manquant' => 'پرونده‌ي ناقص',
	'fichier_modifie' => 'پرونده اصلاح شده است. روي ثبت كليك كنيد.',
	'format_date_incorrect' => 'تاريخ يا ساعت درست نيستند',

	// I
	'icone_creer_document' => 'افزودن يك سند',
	'id' => 'آي.دي',
	'image_tourner_180' => 'چرخش °١٨٠ ',
	'image_tourner_droite' => 'چرخش ٩٠ درجه به راست',
	'image_tourner_gauche' => 'چرخش ٩٠ درجه به چپ',
	'info_doc_max_poids' => 'سندها الزاماً بايد كم‌تر از @maxi@ باشند. (اين پرونده @actuel@ است(  ',
	'info_document' => 'سند',
	'info_document_indisponible' => 'این سند موجود نمیباشد',
	'info_documents' => 'اسناد',
	'info_gauche_numero_document' => 'شماره‌ي سند',
	'info_hauteur' => 'بلندي',
	'info_heure' => 'ساعت',
	'info_illustrations' => 'ترسيم‌ها',
	'info_image_max_poids' => 'تصويرها بايد الزام كم‌تر از @maxi@ باشند(اين پرونده @actuel@ است).',
	'info_image_max_taille' => 'تصويرها بايد الزام كم‌تر از @maxi@ باشند(اين پرونده @actuel@ است).',
	'info_inclusion_directe' => ': گنجاندن مستقيم',
	'info_inclusion_vignette' => ': گنجاندن تصاوير كوچك شده',
	'info_installer_tous_documents' => 'تمام اسناد را مستقر كنيد',
	'info_largeur' => 'درازا',
	'info_logo_max_taille' => 'لوگوها بايد كمتر از @maxi@ باشند(اين فايل است)',
	'info_modifier_document' => 'اصلاح سند ',
	'info_portfolio' => 'كارنامه',
	'info_referencer_doc_distant' => 'يك پرونده را در اينترنت ضبط كنيد:',
	'info_sans_vignette' => 'بدون صورتك ',
	'info_statut_document' => 'اين سند :',
	'info_telecharger' => ':با رايانه خودتان بارگذارى كنيد',
	'infos' => ' نمايش اطلاعات روي تمام بخش‌ها (اگرمي‌خواهيد استفاده‌ي متفاوتي از آن بشود)',
	'item_autoriser_selectionner_date_en_ligne' => 'دادن اجازه‌ي اصلاح تاريخ هر سند',
	'item_non_autoriser_selectionner_date_en_ligne' => 'تاريخ سند‌ها تاريخ افزوده شدن‌ آن‌ها به سايت است',

	// L
	'label_activer_document_objets' => 'فعال سازي بارگذاري براي اين مطالب: ',
	'label_apercu' => 'مرور',
	'label_caracteristiques' => 'ويژگي‌ها',
	'label_credits' => 'اعتبارها',
	'label_fichier' => 'پرونده',
	'label_fichier_vignette' => 'ويگنت',
	'label_paginer_par' => 'شماره صفحه‌گذاري با: ',
	'label_parents' => 'اين سند پيوند خورده به ',
	'label_refdoc_joindre' => 'شماره‌ي سند',
	'lien_tout_enlever' => 'حذف همه', # MODIF
	'logo' => 'لوگو',

	// M
	'media_audio' => 'تراك صدا',
	'media_file' => 'ديگران',
	'media_image' => 'تصويرها',
	'media_video' => 'سكانس‌ها',
	'miniature_automatique_active' => ' اسپيپ به طور خوكار يك مينياتور از تصوير درست مي‌كند',

	// N
	'nb_documents_attache_succes' => '@nb@ سند افزوده شه است',
	'nb_documents_installe_succes' => '@nb@ پرونده با موفقيت بارگداري شده',

	// O
	'objet_document' => 'سند',
	'objet_documents' => 'سندها',

	// P
	'par_date' => 'بر اساس تاريخ',
	'par_hauteur' => 'بلندي',
	'par_id' => 'آي.دي',
	'par_largeur' => 'درازا',
	'par_taille' => 'وزن',
	'par_titre' => 'بر اساس تيتر',

	// T
	'texte_documents_joints' => 'مي‌توانيد واسطه‌ي افزودن سندها (فايل‌هاي اداري، تصويرها، و چندرسانه‌اي و غيره) را به مقاله‌ها، بخش‌ها و غيره فعال كنيد. به اين پرونده‌ها بعداً مي‌توان در متن، ارجاع كرد يا آن‌ها را جداگانه به نمايش گذاشت.</p> ',
	'texte_documents_joints_2' => 'اين تنظيم نه از بارگذاري تصاوير در مقالات و نه از گنجاندن مستقيم سند در مت‌هاي مطالب جلوگيرى نمي‌كند.',
	'titre_documents_joints' => 'اسناد پيوسته',
	'titre_page_documents_edit' => 'اصلاح سند : @titre@',
	'tous_les_medias' => 'تمام رسانه‌ها',
	'tout_dossier_upload' => 'تمام پرونده @upload@',
	'tout_voir' => 'ديدن همه',

	// U
	'un_audio' => '1 تراك صدا',
	'un_document' => '1 سند',
	'un_file' => '1 سند',
	'un_image' => '1 تصوير',
	'un_video' => '1 سكانس',
	'une_utilisation' => '1اسفتاده',
	'upload_fichier_zip' => 'فايل فشرده ZIP',
	'upload_fichier_zip_texte' => 'فايلى كه شما پيشنهاد نصب آنرا ميكنيد يك فايل  ZIP ميباشد.',
	'upload_fichier_zip_texte2' => 'اين فايل ميتواند',
	'upload_info_mode_document' => 'گذاشتن اين تصويرها در شرح‌ حال',
	'upload_info_mode_image' => 'برداشتن اين تصوير از شرح حال',
	'upload_limit' => 'اين فايل براى سرور بسيار بزرگ است حداكثر اندازه ى مجاز <i>upload</i> @max@ ميباشد',
	'upload_zip_conserver' => 'حفظ كردن فايل آرشيوي پس از استخراج محتواي آن',
	'upload_zip_decompacter' => 'باز شود و هر عنصر محتوى آن ميتواند بروى سايت نصب شود. فايلهايى كه بدين صورت نصب ميشوند',
	'upload_zip_mode_document' => 'گذاشتن تمام اين تصويرها در شرح حال',
	'upload_zip_telquel' => 'بهمان صورت نصب شده اند بصورت بايگانى ZIP',
	'upload_zip_titrer' => 'مطابق با نام پرونده تيترگذاري كن',

	// V
	'verifier_documents_brises' => 'اصلاح پرونده‌هاي ناقص',
	'verifier_documents_inutilises' => 'تأييد پيوند‌ها به سندها',
	'vignette_supprimee' => 'ويگنت‌ها حذف شده‌اند',
];
